@@ -4,12 +4,12 @@ lokalise.collections.branches
 Module containing branches collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.branch import BranchModel
+from .base_collection import BaseCollection
 
 
-class BranchesCollection(BaseCollection):
-    """Describes project branches.
-    """
+class BranchesCollection(BaseCollection[BranchModel]):
+    """Describes project branches."""
+
     DATA_KEY = "branches"
     MODEL_KLASS = BranchModel
