@@ -4,12 +4,12 @@ lokalise.collections.glossary_terms
 Module containing glossary terms collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.glossary_term import GlossaryTermModel
+from .base_collection import BaseCollection
 
 
-class GlossaryTermsCollection(BaseCollection):
-    """Describes glossary terms.
-    """
+class GlossaryTermsCollection(BaseCollection[GlossaryTermModel]):
+    """Describes glossary terms."""
+
     DATA_KEY = "data"
     MODEL_KLASS = GlossaryTermModel
