@@ -4,12 +4,12 @@ lokalise.collections.keys
 Module containing keys collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.key import KeyModel
+from .base_collection import BaseCollection
 
 
-class KeysCollection(BaseCollection):
-    """Describes keys.
-    """
+class KeysCollection(BaseCollection[KeyModel]):
+    """Describes keys."""
+
     DATA_KEY = "keys"
     MODEL_KLASS = KeyModel
