@@ -4,12 +4,12 @@ lokalise.collections.languages
 Module containing languages collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.language import LanguageModel
+from .base_collection import BaseCollection
 
 
-class LanguagesCollection(BaseCollection):
-    """Describes system and project languages.
-    """
+class LanguagesCollection(BaseCollection[LanguageModel]):
+    """Describes system and project languages."""
+
     DATA_KEY = "languages"
     MODEL_KLASS = LanguageModel
