@@ -4,12 +4,12 @@ lokalise.collections.projects
 Module containing projects collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.project import ProjectModel
+from .base_collection import BaseCollection
 
 
-class ProjectsCollection(BaseCollection):
-    """Describes projects.
-    """
+class ProjectsCollection(BaseCollection[ProjectModel]):
+    """Describes projects."""
+
     DATA_KEY = "projects"
     MODEL_KLASS = ProjectModel
