@@ -4,12 +4,12 @@ lokalise.collections.segments
 Module containing segments collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.segment import SegmentModel
+from .base_collection import BaseCollection
 
 
-class SegmentsCollection(BaseCollection):
-    """Describes segments.
-    """
+class SegmentsCollection(BaseCollection[SegmentModel]):
+    """Describes segments."""
+
     DATA_KEY = "segments"
     MODEL_KLASS = SegmentModel
