@@ -4,12 +4,12 @@ lokalise.collections.snapshots
 Module containing snapshots collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.snapshot import SnapshotModel
+from .base_collection import BaseCollection
 
 
-class SnapshotsCollection(BaseCollection):
-    """Describes snapshots.
-    """
+class SnapshotsCollection(BaseCollection[SnapshotModel]):
+    """Describes snapshots."""
+
     DATA_KEY = "snapshots"
     MODEL_KLASS = SnapshotModel
