@@ -4,12 +4,12 @@ lokalise.collections.translations
 Module containing translations collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.translation import TranslationModel
+from .base_collection import BaseCollection
 
 
-class TranslationsCollection(BaseCollection):
-    """Describes translations.
-    """
+class TranslationsCollection(BaseCollection[TranslationModel]):
+    """Describes translations."""
+
     DATA_KEY = "translations"
     MODEL_KLASS = TranslationModel
